The file `pendulum_3d.mat` has been generated using `metis` by PLK.
The content of file `pendulum_3d.mat`
is parsed in script `s005_run_pendulum_3d.py`
and exported to file `pendulum_3d.csv`.

On the contrary, the file `test/reference_results/pendulum_3d.csv` is calculated with `pydykit`.
